@@ -14,13 +14,10 @@ Variant <- R6::R6Class(
     #' @field variant The variant.
     variant = NULL,
     #' @description Get the underlying variant data.
-    get_variant = function() {
-      self$variant
-    },
     #' @description Get and store the (remote) variant data.
     get_variant_remote = function() {
-      path <- unversioned_url("variants", self$get_variant()$id)
-      self$variant <- self$get_connect()$GET(path)
+      path <- unversioned_url("variants", self$variant$id)
+      self$variant <- self$connect$GET(path)
       self$variant
     },
     #' @description Initialize this variant.
@@ -44,12 +41,12 @@ Variant <- R6::R6Class(
       to = c("me", "collaborators", "collaborators_viewers")
     ) {
       warn_experimental("send_mail")
-      url <- unversioned_url("variants", self$get_variant()$id, "sender")
-      self$get_connect()$POST(
+      url <- unversioned_url("variants", self$variant$id, "sender")
+      self$connect$POST(
         path = url,
         query = list(
           email = arg_match(to),
-          rendering_id = self$get_variant()$rendering_id
+          rendering_id = self$variant$rendering_id
         )
       )
     },
@@ -60,8 +57,8 @@ Variant <- R6::R6Class(
     #' @description Get the (remote) schedule data.
     get_schedule_remote = function() {
       warn_experimental("get_schedule_remote")
-      url <- unversioned_url("variants", self$get_variant()$id, "schedules")
-      res <- self$get_connect()$GET(url)
+      url <- unversioned_url("variants", self$variant$id, "schedules")
+      res <- self$connect$GET(url)
 
       if (length(res) == 1) {
         res <- res[[1]]
@@ -69,7 +66,7 @@ Variant <- R6::R6Class(
 
       if (length(res) > 0) {
         # add the content guid and variant key
-        content_guid <- self$get_content()$guid
+        content_guid <- self$content$guid
         variant_key <- self$key
         res <- purrr::list_modify(
           res,
@@ -83,36 +80,32 @@ Variant <- R6::R6Class(
     #' @description Get the subscribers.
     get_subscribers = function() {
       warn_experimental("subscribers")
-      path <- unversioned_url("variants", self$get_variant()$id, "subscribers")
-      self$get_connect()$GET(path)
+      path <- unversioned_url("variants", self$variant$id, "subscribers")
+      self$connect$GET(path)
     },
     #' @description Remove a named subscriber.
     #' @param guid User GUID.
     remove_subscriber = function(guid) {
       warn_experimental("subscribers")
-      path <- unversioned_url(
-        "variants",
-        self$get_variant()$id,
-        "subscribers",
-        guid
-      )
-      self$get_connect()$DELETE(path)
+      id <- self$variant$id
+      path <- unversioned_url("variants", id, "subscribers", guid)
+      self$connect$DELETE(path)
     },
     #' @description Add named subscribers.
     #' @param guids User GUIDs.
     add_subscribers = function(guids) {
       warn_experimental("subscribers")
-      path <- unversioned_url("variants", self$get_variant()$id, "subscribers")
-      self$get_connect()$POST(path = path, body = guids)
+      path <- unversioned_url("variants", self$variant$id, "subscribers")
+      self$connect$POST(path = path, body = guids)
     },
     #' @description Render this variant.
     render = function() {
       warn_experimental("render")
-      path <- unversioned_url("variants", self$get_variant()$id, "render")
-      res <- self$get_connect()$POST(path)
+      path <- unversioned_url("variants", self$variant$id, "render")
+      res <- self$connect$POST(path)
 
       # add the content guid and variant key
-      content_guid <- self$get_content()$guid
+      content_guid <- self$content$guid
       variant_key <- self$key
 
       purrr::list_modify(
@@ -124,10 +117,10 @@ Variant <- R6::R6Class(
     #' @description List the renderings of this variant.
     renderings = function() {
       warn_experimental("renderings")
-      url <- unversioned_url("variants", self$get_variant()$id, "renderings")
-      res <- self$get_connect()$GET(path = url)
+      url <- unversioned_url("variants", self$variant$id, "renderings")
+      res <- self$connect$GET(path = url)
       # add the content guid and variant key
-      content_guid <- self$get_content()$guid
+      content_guid <- self$content$guid
       variant_key <- self$key
 
       purrr::map(
@@ -144,8 +137,8 @@ Variant <- R6::R6Class(
     update_variant = function(...) {
       params <- rlang::list2(...)
       # TODO: allow updating a variant
-      url <- unversioned_url("variants", self$get_variant()$id)
-      res <- self$get_connect()$POST(url, body = params)
+      url <- unversioned_url("variants", self$variant$id)
+      res <- self$connect$POST(url, body = params)
       return(self)
     },
     #' @description Jobs for this variant.
@@ -180,7 +173,7 @@ Variant <- R6::R6Class(
     #' @param pane The pane in the dashboard to link to.
     get_dashboard_url = function(pane = "access") {
       base_content <- super$get_dashboard_url("")
-      glue::glue("{base_content}{pane}/{self$get_variant()$id}")
+      glue::glue("{base_content}{pane}/{self$variant$id}")
     },
     # nolint start: commented_code_linter
     # TODO: dashboard cannot navigate directly to renderings today
@@ -284,8 +277,8 @@ get_variant <- function(content, key) {
   scoped_experimental_silence()
   validate_R6_class(content, "Content")
   Variant$new(
-    connect = content$get_connect(),
-    content = content$get_content(),
+    connect = content$connect,
+    content = content$content,
     key = key
   )
 }
@@ -329,8 +322,8 @@ variant_render <- function(variant) {
   rendered <- variant$render()
 
   VariantTask$new(
-    connect = variant$get_connect(),
-    content = variant$get_content(),
+    connect = variant$connect,
+    content = variant$content,
     key = variant$key,
     task = rendered
   )
